@@ -216,9 +216,9 @@ proc_dhe_server_kx (gnutls_session_t session, opaque * data,
   signature.size = sigsize;
 
   if ((ret =
-       _gnutls_raw_cert_to_gcert (&peer_cert,
+       _gnutls_get_auth_info_gcert (&peer_cert,
 				  session->security_parameters.cert_type,
-				  &info->raw_certificate_list[0],
+				  info,
 				  CERT_NO_COPY)) < 0)
     {
       gnutls_assert ();
