@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2005, 2007 Free Software Foundation
+ * Copyright (C) 2005, 2007, 2008 Free Software Foundation
  *
  * Author: Nikos Mavrogiannopoulos
  *
@@ -147,12 +147,12 @@ error:
 }
 
 /**
-  * gnutls_psk_free_server_credentials - Used to free an allocated gnutls_psk_server_credentials_t structure
-  * @sc: is an #gnutls_psk_server_credentials_t structure.
-  *
-  * This structure is complex enough to manipulate directly thus this
-  * helper function is provided in order to free (deallocate) it.
-  **/
+ * gnutls_psk_free_server_credentials - Used to free an allocated gnutls_psk_server_credentials_t structure
+ * @sc: is an #gnutls_psk_server_credentials_t structure.
+ *
+ * This structure is complex enough to manipulate directly thus this
+ * helper function is provided in order to free (deallocate) it.
+ **/
 void
 gnutls_psk_free_server_credentials (gnutls_psk_server_credentials_t sc)
 {
@@ -161,14 +161,14 @@ gnutls_psk_free_server_credentials (gnutls_psk_server_credentials_t sc)
 }
 
 /**
-  * gnutls_psk_allocate_server_credentials - Used to allocate an gnutls_psk_server_credentials_t structure
-  * @sc: is a pointer to an #gnutls_psk_server_credentials_t structure.
-  *
-  * This structure is complex enough to manipulate directly thus this
-  * helper function is provided in order to allocate it.
-  *
-  * Returns: %GNUTLS_E_SUCCESS on success, or an error code.
-  **/
+ * gnutls_psk_allocate_server_credentials - Used to allocate an gnutls_psk_server_credentials_t structure
+ * @sc: is a pointer to an #gnutls_psk_server_credentials_t structure.
+ *
+ * This structure is complex enough to manipulate directly thus this
+ * helper function is provided in order to allocate it.
+ *
+ * Returns: %GNUTLS_E_SUCCESS on success, or an error code.
+ **/
 int
 gnutls_psk_allocate_server_credentials (gnutls_psk_server_credentials_t * sc)
 {
@@ -182,16 +182,16 @@ gnutls_psk_allocate_server_credentials (gnutls_psk_server_credentials_t * sc)
 
 
 /**
-  * gnutls_psk_set_server_credentials_file - Used to set the password files, in a gnutls_psk_server_credentials_t structure
-  * @res: is an #gnutls_psk_server_credentials_t structure.
-  * @password_file: is the PSK password file (passwd.psk)
-  *
-  * This function sets the password file, in a
-  * %gnutls_psk_server_credentials_t structure.  This password file
-  * holds usernames and keys and will be used for PSK authentication.
-  *
-  * Returns: %GNUTLS_E_SUCCESS on success, or an error code.
-  **/
+ * gnutls_psk_set_server_credentials_file - Used to set the password files, in a gnutls_psk_server_credentials_t structure
+ * @res: is an #gnutls_psk_server_credentials_t structure.
+ * @password_file: is the PSK password file (passwd.psk)
+ *
+ * This function sets the password file, in a
+ * %gnutls_psk_server_credentials_t structure.  This password file
+ * holds usernames and keys and will be used for PSK authentication.
+ *
+ * Returns: %GNUTLS_E_SUCCESS on success, or an error code.
+ **/
 int
 gnutls_psk_set_server_credentials_file (gnutls_psk_server_credentials_t
 					res, const char *password_file)
@@ -220,27 +220,54 @@ gnutls_psk_set_server_credentials_file (gnutls_psk_server_credentials_t
   return 0;
 }
 
+/**
+ * gnutls_psk_set_server_credentials_hint - Set a identity hint, in a %gnutls_psk_server_credentials_t structure
+ * @res: is an #gnutls_psk_server_credentials_t structure.
+ * @hint: is the PSK identity hint string
+ *
+ * This function sets the identity hint, in a
+ * %gnutls_psk_server_credentials_t structure.  This hint is sent to
+ * the client to help it chose a good PSK credential (i.e., username
+ * and password).
+ *
+ * Returns: %GNUTLS_E_SUCCESS on success, or an error code.
+ *
+ * Since: 2.4.0
+ **/
+int
+gnutls_psk_set_server_credentials_hint (gnutls_psk_server_credentials_t res,
+					const char *hint)
+{
+  res->hint = gnutls_strdup (hint);
+  if (res->hint == NULL)
+    {
+      gnutls_assert ();
+      return GNUTLS_E_MEMORY_ERROR;
+    }
+
+  return 0;
+}
 
 /**
-  * gnutls_psk_set_server_credentials_function - Used to set a callback to retrieve the user's PSK credentials
-  * @cred: is a #gnutls_psk_server_credentials_t structure.
-  * @func: is the callback function
-  *
-  * This function can be used to set a callback to retrieve the user's PSK credentials.
-  * The callback's function form is:
-  * int (*callback)(gnutls_session_t, const char* username,
-  *  gnutls_datum_t* key);
-  *
-  * @username contains the actual username. 
-  * The @key must be filled in using the gnutls_malloc(). 
-  *
-  * In case the callback returned a negative number then gnutls will
-  * assume that the username does not exist.
-  *
-  * The callback function will only be called once per handshake.  The
-  * callback function should return 0 on success, while -1 indicates
-  * an error.
-  **/
+ * gnutls_psk_set_server_credentials_function - Used to set a callback to retrieve the user's PSK credentials
+ * @cred: is a #gnutls_psk_server_credentials_t structure.
+ * @func: is the callback function
+ *
+ * This function can be used to set a callback to retrieve the user's PSK credentials.
+ * The callback's function form is:
+ * int (*callback)(gnutls_session_t, const char* username,
+ *  gnutls_datum_t* key);
+ *
+ * @username contains the actual username.
+ * The @key must be filled in using the gnutls_malloc().
+ *
+ * In case the callback returned a negative number then gnutls will
+ * assume that the username does not exist.
+ *
+ * The callback function will only be called once per handshake.  The
+ * callback function should return 0 on success, while -1 indicates
+ * an error.
+ **/
 void
 gnutls_psk_set_server_credentials_function (gnutls_psk_server_credentials_t
 					    cred,
@@ -251,25 +278,25 @@ gnutls_psk_set_server_credentials_function (gnutls_psk_server_credentials_t
 }
 
 /**
-  * gnutls_psk_set_client_credentials_function - Used to set a callback to retrieve the username and key
-  * @cred: is a #gnutls_psk_server_credentials_t structure.
-  * @func: is the callback function
-  *
-  * This function can be used to set a callback to retrieve the username and
-  * password for client PSK authentication.
-  * The callback's function form is:
-  * int (*callback)(gnutls_session_t, char** username,
-  *  gnutls_datum_t* key);
-  *
-  * The @username and @key must be allocated using gnutls_malloc().
-  * @username should be ASCII strings or UTF-8 strings prepared using
-  * the "SASLprep" profile of "stringprep".
-  *
-  * The callback function will be called once per handshake.
-  *
-  * The callback function should return 0 on success.
-  * -1 indicates an error.
-  **/
+ * gnutls_psk_set_client_credentials_function - Used to set a callback to retrieve the username and key
+ * @cred: is a #gnutls_psk_server_credentials_t structure.
+ * @func: is the callback function
+ *
+ * This function can be used to set a callback to retrieve the username and
+ * password for client PSK authentication.
+ * The callback's function form is:
+ * int (*callback)(gnutls_session_t, char** username,
+ *  gnutls_datum_t* key);
+ *
+ * The @username and @key->data must be allocated using gnutls_malloc().
+ * @username should be ASCII strings or UTF-8 strings prepared using
+ * the "SASLprep" profile of "stringprep".
+ *
+ * The callback function will be called once per handshake.
+ *
+ * The callback function should return 0 on success.
+ * -1 indicates an error.
+ **/
 void
 gnutls_psk_set_client_credentials_function (gnutls_psk_client_credentials_t
 					    cred,
@@ -281,14 +308,14 @@ gnutls_psk_set_client_credentials_function (gnutls_psk_client_credentials_t
 
 
 /**
-  * gnutls_psk_server_get_username - return the username of the peer
-  * @session: is a gnutls session
-  *
-  * This should only be called in case of PSK authentication and in
-  * case of a server.
-  *
-  * Returns: the username of the peer, or %NULL in case of an error.
-  **/
+ * gnutls_psk_server_get_username - return the username of the peer
+ * @session: is a gnutls session
+ *
+ * This should only be called in case of PSK authentication and in
+ * case of a server.
+ *
+ * Returns: the username of the peer, or %NULL in case of an error.
+ **/
 const char *
 gnutls_psk_server_get_username (gnutls_session_t session)
 {
@@ -306,6 +333,35 @@ gnutls_psk_server_get_username (gnutls_session_t session)
   return NULL;
 }
 
+/**
+ * gnutls_psk_client_get_hint - return the PSK identity hint of the peer
+ * @session: is a gnutls session
+ *
+ * The PSK identity hint may give the client help in deciding which
+ * username to use.  This should only be called in case of PSK
+ * authentication and in case of a client.
+ *
+ * Returns: the identity hint of the peer, or %NULL in case of an error.
+ *
+ * Since: 2.4.0
+ **/
+const char *
+gnutls_psk_client_get_hint (gnutls_session_t session)
+{
+  psk_auth_info_t info;
+
+  CHECK_AUTH (GNUTLS_CRD_PSK, NULL);
+
+  info = _gnutls_get_auth_info (session);
+  if (info == NULL)
+    return NULL;
+
+  if (info->hint[0] != 0)
+    return info->hint;
+
+  return NULL;
+}
+
 /**
   * gnutls_hex_decode - decode hex encoded data
   * @hex_data: contain the encoded data
